#from .run_all import run_all
#from .example_3D import example_3D
#from .example_2D import example_2D
#from .example_1D import example_1D
from .test_init import test_init
from .test_init_device import test_init_device
# from .test_init2 import test_init2
# from .test_init3 import test_init3
#from .test_cuda import test_cuda
#from .test_2D import test_2D
#from .test_installation import test_installation
